==> haskell-configfile-1.1.4-51-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ConfigFile
version: 1.1.4
id: ConfigFile-1.1.4-D1M3tnwfVDW29kJwrRTcHW
key: ConfigFile-1.1.4-D1M3tnwfVDW29kJwrRTcHW
license: BSD-3-Clause
copyright: Copyright (c) 2004-2014 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/configfile
synopsis: Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.
    .
    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.
    .
    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.
category: Parsing
abi: b03a1e6c0f44970ce74e8477aa158beb
exposed: True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types
hidden-modules: Data.ConfigFile.Lexer
import-dirs: /usr/lib/ghc-8.6.4/site-local/ConfigFile-1.1.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/ConfigFile-1.1.4
hs-libraries: HSConfigFile-1.1.4-D1M3tnwfVDW29kJwrRTcHW
depends:
    MissingH-1.4.1.0-I2zOReBQx15IibN5Exv24v base-4.12.0.0
    containers-0.6.0.1 mtl-2.2.2 parsec-3.1.13.0
haddock-interfaces: /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html: /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configfile-1.1.4-52-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ConfigFile
version: 1.1.4
id: ConfigFile-1.1.4-BhFntKsFydeBoc8VvaHCKX
key: ConfigFile-1.1.4-BhFntKsFydeBoc8VvaHCKX
license: BSD-3-Clause
copyright: Copyright (c) 2004-2014 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/configfile
synopsis: Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.
    .
    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.
    .
    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.
category: Parsing
abi: bf5ecae0a7882b6e3a583bf153097a1e
exposed: True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types
hidden-modules: Data.ConfigFile.Lexer
import-dirs: /usr/lib/ghc-8.6.4/site-local/ConfigFile-1.1.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/ConfigFile-1.1.4
hs-libraries: HSConfigFile-1.1.4-BhFntKsFydeBoc8VvaHCKX
depends:
    MissingH-1.4.1.0-Bq0DDygr7EXByDnnV67Lyl base-4.12.0.0
    containers-0.6.0.1 mtl-2.2.2 parsec-3.1.13.0
haddock-interfaces: /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html: /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
